#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_IS_INCLUDED_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_IS_INCLUDED_HPP_INCLUDED

#include <boost/simd/reduction/include/functions/is_included.hpp>

#endif
